@@ -5,7 +5,7 @@ use Exporter 'import';
 use Carp;
 use Clone qw/clone/;
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 our @EXPORT_OK = qw/hatx/;
 
 =head1 NAME
@@ -75,7 +75,7 @@ HATX - A fluent interface for Hash and Array Transformations
       return $ver eq $res->{$file};
     }, $max)
     # Internal object reduced to:
-    #   ['journal', '1.2', 3100]
+    # [ ['journal', '1.2', 3100]
     #   ['projmgmt', '0.2', 350] ]
   ;
 
@@ -196,6 +196,43 @@ sub grep {
     return $o;
 }
 
+=head2 sort( $fn )
+
+DESCRIPTION
+
+    Sorts contents of arrayref. Hashrefs are unmodified.
+
+ARGUMENTS
+
+    $fn - A function reference with prototype ($$). See https://perldoc.perl.org/functions/sort.
+
+EXAMPLES
+
+    # Sort descending alphabetically
+    hatx($aref)->sort(sub ($$) { $_[1] cmp $_[0] });
+
+    # Sort ascending numerically
+    hatx($aref)->sort(sub ($$) { $_[0] <=> $_[1] });
+
+    # Sort descending numerically
+    hatx($aref)->sort(sub ($$) { $_[1] <=> $_[0] });
+
+=cut
+sub sort ($&) {
+    my $o = shift;
+    my $fn = shift;     # A: $fn is a BLOCK
+
+    if (defined($o->{H})) {
+        # do nothing
+    }
+    if (defined($o->{A})) {
+        $o->{A} = defined $fn ? [ sort $fn @{$o->{A}} ]
+                              : [ sort @{$o->{A}} ];
+    }
+
+    return $o;
+}
+
 =head2 to_href
 
 Convert internal aref to href using the given function.
@@ -213,6 +250,44 @@ sub to_href {
     return $o;
 }
 
+=head2 to_aref( $fn [,@args] )
+
+DESCRIPTION
+
+    Convert internal hashref to an arrayref.
+
+ARGUMENTS
+
+    $fn - A user-provided function reference with signature:
+
+      $fn->($hkey, $hval [,@args]) return ($val)
+
+      WHERE
+        $hkey   Key of source hashref pair
+        $hval   Value of source hashref pair
+        @args   Optional user variables
+        $val    An element of the target arrayref
+
+    @args - Optional arguments that are passed through to $fn
+
+=cut
+sub to_aref {
+    my ($o,$fn,@args) = @_;
+
+    if (defined($o->{H})) {
+        my $new_A = [];
+        foreach my $k (keys %{$o->{H}}) {
+            push @$new_A, $fn->($k,$o->{H}{$k},@args);
+        }
+        $o->{A} = $new_A;
+        $o->{H} = undef;
+    } else {
+        croak 'HATX/to_aref: No hashref to transform.';
+    }
+
+    return $o;
+}
+
 =head2 apply
 
 Apply the given function to each item in the href/aref. Arguments can be
